<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * Generic filter class.
 * All filters <b>must</b> derive from this class
 */
abstract class myMVC_BaseFilter
{
  protected $request;
  protected $session;
  protected $param;
  protected $filterType;
  protected $calledClass;

  /**
   * Constructor.
   * 
   * @param myMVC_HttpRequest $request      The Request
   * @param myMVC_HttpSession $session      The session
   * @param class $calledClass              The called class (subclass of myMVC_BaseAction or myMVC_BaseView)
   * @param string $filterType              Filter type (PREACTION or PREVIEW)
   * @param array $param                    The optional parameters of the filter
   */
  public function __construct($request, $session, $calledClass, $filterType, $param = array())
  {
    $this->request = $request;
    $this->session = $session;
    $this->calledClass = $calledClass;
    $this->filterType = $filterType;
    $this->param = $param;
  }

  /**
   * Do the job.
   * If the Controller has to call an action, returns an instance of
   * myMVC_HttpResponse, otherwise NULL
   * 
   * @return myMVC_HttpResponse             Response code for an Action or NULL, if the program should continue
   */
  abstract public function filter();
}
?>
